package com.qmth.sop.server.api;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.sop.business.bean.query.UserArchivesQuery;
import com.qmth.sop.business.entity.TBTask;
import com.qmth.sop.business.service.TBTaskService;
import com.qmth.sop.business.templete.execute.AsyncUserArchivesExportService;
import com.qmth.sop.business.templete.execute.AsyncUserArchivesImportService;
import com.qmth.sop.common.contant.SystemConstant;
import com.qmth.sop.common.enums.RoleTypeEnum;
import com.qmth.sop.common.enums.TaskTypeEnum;
import com.qmth.sop.common.util.Result;
import com.qmth.sop.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.util.Map;

/**
 * <p>
 * 人员档案表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2023-07-17
 */
@Api(tags = "人员档案Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + SystemConstant.PREFIX_URL_USER_ARCHIVES)
public class TBUserArchivesController {

    @Resource
    TBTaskService tbTaskService;

    @Resource
    AsyncUserArchivesImportService asyncUserArchivesImportService;

    @Resource
    AsyncUserArchivesExportService asyncUserArchivesExportService;

    @ApiOperation(value = "人员档案导入")
    @RequestMapping(value = "/import", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "返回信息", response = Object.class)})
    public Result importUserArchives(@ApiParam(value = "上传文件", required = true) @RequestParam MultipartFile file) throws Exception {
        Map<String, Object> map = tbTaskService.saveTask(file, TaskTypeEnum.USER_ARCHIVES_IMPORT);
        asyncUserArchivesImportService.importTask(map);
        TBTask tbTask = (TBTask) map.get(SystemConstant.TASK);
        return ResultUtil.ok(tbTask.getId());
    }

    @ApiOperation(value = "人员档案导出")
    @RequestMapping(value = "/export", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "返回信息", response = Object.class)})
    public Result exportUserArchives(@ApiParam(value = "城市") @RequestParam(required = false) String city,
                                     @ApiParam(value = "供应商") @RequestParam(required = false) String supplierId,
                                     @ApiParam(value = "档案名") @RequestParam(required = false) String archivesName,
                                     @ApiParam(value = "角色类型") @RequestParam(required = false) RoleTypeEnum roleType,
                                     @ApiParam(value = "认证状态") @RequestParam(required = false) Boolean authenticationStatus,
                                     @ApiParam(value = "入档时间 - 起始") @RequestParam(required = false) Long archivesTimeStart,
                                     @ApiParam(value = "入档时间 - 截止") @RequestParam(required = false) Long archivesTimeEnd,
                                     @ApiParam(value = "有效期") @RequestParam(required = false) Integer remainValidDay) throws Exception {
        Map<String, Object> map = tbTaskService.saveTask(TaskTypeEnum.USER_ARCHIVES_EXPORT);
        UserArchivesQuery query = new UserArchivesQuery();
        query.setCity(city);
        query.setSupplierId(SystemConstant.convertIdToLong(supplierId));
        query.setArchivesName(archivesName);
        query.setRoleType(roleType);
        query.setAuthenticationStatus(authenticationStatus);
        query.setArchivesTimeStart(archivesTimeStart);
        query.setArchivesTimeEnd(archivesTimeEnd);
        query.setRemainValidDay(remainValidDay);
        map.put(SystemConstant.QUERY, query);
        asyncUserArchivesExportService.exportTask(map);
        TBTask tbTask = (TBTask) map.get(SystemConstant.TASK);
        return ResultUtil.ok(tbTask.getId());
    }
}